@@ -180,3 +180,13 @@ def check_anchorname_char(ch):
     if ch in u',[]{}':
         return False
     return check_namespace_char(ch)
+
+
+def version_tnf(t1, t2=None):
+    # type: (Any, Any) -> Any
+    from ruamel.yaml import version_info  # NOQA
+    if version_info < t1:
+        return True
+    if t2 is not None and version_info < t2:
+        return None
+    return False
